==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/gpm/v20200820/models/MatchCodeAttr.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.gpm.v20200820.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class MatchCodeAttr extends AbstractModel{

    /**
    * 匹配code
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("MatchCode")
    @Expose
    private String MatchCode;

    /**
     * Get 匹配code
注意：此字段可能返回 null，表示取不到有效值。 
     * @return MatchCode 匹配code
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String getMatchCode() {
        return this.MatchCode;
    }

    /**
     * Set 匹配code
注意：此字段可能返回 null，表示取不到有效值。
     * @param MatchCode 匹配code
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setMatchCode(String MatchCode) {
        this.MatchCode = MatchCode;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "MatchCode", this.MatchCode);

    }
}

==> tencentcloud-sdk-java-3.1.281-sources.jar: com/tencentcloudapi/gpm/v20200820/models/MatchCodeAttr.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.gpm.v20200820.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class MatchCodeAttr extends AbstractModel{

    /**
    * 匹配code
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("MatchCode")
    @Expose
    private String MatchCode;

    /**
     * Get 匹配code
注意：此字段可能返回 null，表示取不到有效值。 
     * @return MatchCode 匹配code
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String getMatchCode() {
        return this.MatchCode;
    }

    /**
     * Set 匹配code
注意：此字段可能返回 null，表示取不到有效值。
     * @param MatchCode 匹配code
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setMatchCode(String MatchCode) {
        this.MatchCode = MatchCode;
    }

    public MatchCodeAttr() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public MatchCodeAttr(MatchCodeAttr source) {
        if (source.MatchCode != null) {
            this.MatchCode = new String(source.MatchCode);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "MatchCode", this.MatchCode);

    }
}
